.. nima_io documentation master file, created by
   darosio/cookiecutter-python on 2023-07-27
   You can adapt this file completely to your liking, or rewrite using
   sphinx-quickstart, but it should at least contain the root ’toctree’ directive.

Welcome to the documentation for our project! Here you will find information on
how to use our software, how to contribute to the project, and how to track
changes and updates.

- Getting Started

If you are new to the project, start by reading our `README.md
<https://github.com/darosio/nima_io/blob/main/README.md>`_ file, which provides
an overview of the project and its goals.

- Tracking Changes

We use a changelog file to track changes and updates to our project. You can
find our `CHANGELOG.md
<https://github.com/darosio/nima_io/blob/main/CHANGELOG.md>`_ file here.

Our changelog follows the `Keep a Changelog
<https://keepachangelog.com/en/1.0.0/>`_ format, and we tag releases according
to the `Semantic Versioning <https://semver.org/>`_ scheme.

- Our GitHub repository: `https://github.com/darosio/nima_io
  <https://github.com/darosio/nima_io>`_


.. toctree::
   :hidden:
   :caption: Contents:

   click
   tutorials/tutorials
   api/api
   references/references
